#  tests for pydensecrf-1.0rc3-py36h830ac7b_1 (this is a generated file);
print('===== testing package: pydensecrf-1.0rc3-py36h830ac7b_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import numpy as np
import pydensecrf.densecrf as dcrf

d = dcrf.DenseCRF2D(640, 480, 5)  # width, height, nlabels#  --- run_test.py (end) ---

print('===== pydensecrf-1.0rc3-py36h830ac7b_1 OK =====');
print("import: 'pydensecrf'")
import pydensecrf

